#
# Copyright 2017 the original author or authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
This helps loading http_pb2 and annotations_pb2.
Without this, the Python importer will not be able to process the lines:
from google.api import http_pb2 or
from google.api import annotations_pb2
(Without importing these, the protobuf loader will not recognize http options
in the protobuf definitions.)
"""

from importlib import import_module
import os
import sys


class GoogleApiImporter(object):

    def find_module(self, full_name, path=None):
        if full_name == 'google.api':
            self.path = [os.path.dirname(__file__)]
            return self

    def load_module(self, name):
        if name in sys.modules:
            return sys.modules[name]
        full_name = 'python.protos.third_party.' + name
        import_module(full_name)
        module = sys.modules[full_name]
        sys.modules[name] = module
        return module


sys.meta_path.append(GoogleApiImporter())
try:
    from google.api import http_pb2, annotations_pb2
    _ = http_pb2, annotations_pb2
except AssertionError:
    pass



#
# Copyright 2018 the original author or authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Resource Manager will be unique for each OLT device.

It exposes APIs to create/free alloc_ids/onu_ids/gemport_ids. Resource Manager
uses a KV store in backend to ensure resiliency of the data.
"""
import json
import structlog
from bitstring import BitArray
from ast import literal_eval
import shlex
from argparse import ArgumentParser, ArgumentError

from pyvoltha.adapters.common.pon_resource_manager.resource_kv_store import ResourceKvStore


# Used to parse extra arguments to OpenOlt adapter from the NBI
class OltVendorArgumentParser(ArgumentParser):
    # Must override the exit command to prevent it from
    # calling sys.exit().  Return exception instead.
    def exit(self, status=0, message=None):
        raise Exception(message)


class PONResourceManager(object):
    """Implements APIs to initialize/allocate/release alloc/gemport/onu IDs."""

    # Constants to identify resource pool
    ONU_ID = 'ONU_ID'
    ALLOC_ID = 'ALLOC_ID'
    GEMPORT_ID = 'GEMPORT_ID'

    # The resource ranges for a given device vendor_type should be placed
    # at 'resource_manager/<technology>/resource_ranges/<olt_vendor_type>'
    # path on the KV store.
    # If Resource Range parameters are to be read from the external KV store,
    # they are expected to be stored in the following format.
    # Note: All parameters are MANDATORY for now.
    '''
    {
        "onu_id_start": 1,
        "onu_id_end": 127,
        "alloc_id_start": 1024,
        "alloc_id_end": 2816,
        "gemport_id_start": 1024,
        "gemport_id_end": 8960,
        "pon_ports": 16
    }

    '''
    # constants used as keys to reference the resource range parameters from
    # and external KV store.
    ONU_START_IDX = "onu_id_start"
    ONU_END_IDX = "onu_id_end"
    ALLOC_ID_START_IDX = "alloc_id_start"
    ALLOC_ID_END_IDX = "alloc_id_end"
    GEM_PORT_ID_START_IDX = "gemport_id_start"
    GEM_PORT_ID_END_IDX = "gemport_id_end"
    NUM_OF_PON_PORT = "pon_ports"

    # PON Resource range configuration on the KV store.
    # Format: 'resource_manager/<technology>/resource_ranges/<olt_vendor_type>'
    # The KV store backend is initialized with a path prefix and we need to
    # provide only the suffix.
    PON_RESOURCE_RANGE_CONFIG_PATH = 'resource_ranges/{}'

    # resource path suffix
    ALLOC_ID_POOL_PATH = '{}/alloc_id_pool/{}'
    GEMPORT_ID_POOL_PATH = '{}/gemport_id_pool/{}'
    ONU_ID_POOL_PATH = '{}/onu_id_pool/{}'

    # Path on the KV store for storing list of alloc IDs for a given ONU
    # Format: <device_id>/<(pon_intf_id, onu_id)>/alloc_ids
    ALLOC_ID_RESOURCE_MAP_PATH = '{}/{}/alloc_ids'

    # Path on the KV store for storing list of gemport IDs for a given ONU
    # Format: <device_id>/<(pon_intf_id, onu_id)>/gemport_ids
    GEMPORT_ID_RESOURCE_MAP_PATH = '{}/{}/gemport_ids'

    # Constants for internal usage.
    PON_INTF_ID = 'pon_intf_id'
    START_IDX = 'start_idx'
    END_IDX = 'end_idx'
    POOL = 'pool'

    def __init__(self, technology, extra_args, device_id,
                 backend, host, port):
        """
        Create PONResourceManager object.

        :param technology: PON technology
        :param: extra_args: This string contains extra arguments passed during
        pre-provisioning of OLT and specifies the OLT Vendor type
        :param device_id: OLT device id
        :param backend: backend store
        :param host: ip of backend store
        :param port: port on which backend store listens
        :raises exception when invalid backend store passed as an argument
        """
        # logger
        self._log = structlog.get_logger()

        try:
            self.technology = technology
            self.extra_args = extra_args
            self.device_id = device_id
            self.backend = backend
            self.host = host
            self.port = port
            self.olt_vendor = None
            self._kv_store = ResourceKvStore(technology, device_id, backend,
                                             host, port)
            # Below attribute, pon_resource_ranges, should be initialized
            # by reading from KV store.
            self.pon_resource_ranges = dict()
        except Exception as e:
            self._log.exception("exception-in-init")
            raise Exception(e)

    def init_resource_ranges_from_kv_store(self):
        """
        Initialize PON resource ranges with config fetched from kv store.

        :return boolean: True if PON resource ranges initialized else false
        """
        self.olt_vendor = self._get_olt_vendor()
        # Try to initialize the PON Resource Ranges from KV store based on the
        # OLT vendor key, if available
        if self.olt_vendor is None:
            self._log.info("olt-vendor-unavailable--not-reading-from-kv-store")
            return False

        path = self.PON_RESOURCE_RANGE_CONFIG_PATH.format(self.olt_vendor)
        try:
            # get resource from kv store
            result = self._kv_store.get_from_kv_store(path)

            if result is None:
                self._log.debug("resource-range-config-unavailable-on-kvstore")
                return False

            resource_range_config = result

            if resource_range_config is not None:
                self.pon_resource_ranges = json.loads(resource_range_config)
                self._log.debug("Init-resource-ranges-from-kvstore-success",
                                pon_resource_ranges=self.pon_resource_ranges,
                                path=path)
                return True

        except Exception as e:
            self._log.exception("error-initializing-resource-range-from-kv-store",
                                e=e)
        return False

    def init_default_pon_resource_ranges(self, onu_start_idx=1,
                                         onu_end_idx=127,
                                         alloc_id_start_idx=1024,
                                         alloc_id_end_idx=2816,
                                         gem_port_id_start_idx=1024,
                                         gem_port_id_end_idx=8960,
                                         num_of_pon_ports=16):
        """
        Initialize default PON resource ranges

        :param onu_start_idx: onu id start index
        :param onu_end_idx: onu id end index
        :param alloc_id_start_idx: alloc id start index
        :param alloc_id_end_idx: alloc id end index
        :param gem_port_id_start_idx: gemport id start index
        :param gem_port_id_end_idx: gemport id end index
        :param num_of_pon_ports: number of PON ports
        """
        self._log.info("initialize-default-resource-range-values")
        self.pon_resource_ranges[
            PONResourceManager.ONU_START_IDX] = onu_start_idx
        self.pon_resource_ranges[PONResourceManager.ONU_END_IDX] = onu_end_idx
        self.pon_resource_ranges[
            PONResourceManager.ALLOC_ID_START_IDX] = alloc_id_start_idx
        self.pon_resource_ranges[
            PONResourceManager.ALLOC_ID_END_IDX] = alloc_id_end_idx
        self.pon_resource_ranges[
            PONResourceManager.GEM_PORT_ID_START_IDX] = gem_port_id_start_idx
        self.pon_resource_ranges[
            PONResourceManager.GEM_PORT_ID_END_IDX] = gem_port_id_end_idx
        self.pon_resource_ranges[
            PONResourceManager.NUM_OF_PON_PORT] = num_of_pon_ports

    def init_device_resource_pool(self):
        """
        Initialize resource pool for all PON ports.
        """
        i = 0
        while i < self.pon_resource_ranges[PONResourceManager.NUM_OF_PON_PORT]:
            self.init_resource_id_pool(
                pon_intf_id=i,
                resource_type=PONResourceManager.ONU_ID,
                start_idx=self.pon_resource_ranges[
                    PONResourceManager.ONU_START_IDX],
                end_idx=self.pon_resource_ranges[
                    PONResourceManager.ONU_END_IDX])

            i += 1

        # TODO: ASFvOLT16 platform requires alloc and gemport ID to be unique
        # across OLT. To keep it simple, a single pool (POOL 0) is maintained
        # for both the resource types. This may need to change later.
        self.init_resource_id_pool(
            pon_intf_id=0,
            resource_type=PONResourceManager.ALLOC_ID,
            start_idx=self.pon_resource_ranges[
                PONResourceManager.ALLOC_ID_START_IDX],
            end_idx=self.pon_resource_ranges[
                PONResourceManager.ALLOC_ID_END_IDX])

        self.init_resource_id_pool(
            pon_intf_id=0,
            resource_type=PONResourceManager.GEMPORT_ID,
            start_idx=self.pon_resource_ranges[
                PONResourceManager.GEM_PORT_ID_START_IDX],
            end_idx=self.pon_resource_ranges[
                PONResourceManager.GEM_PORT_ID_END_IDX])

    def clear_device_resource_pool(self):
        """
        Clear resource pool of all PON ports.
        """
        i = 0
        while i < self.pon_resource_ranges[PONResourceManager.NUM_OF_PON_PORT]:
            self.clear_resource_id_pool(
                pon_intf_id=i,
                resource_type=PONResourceManager.ONU_ID,
            )
            i += 1

        self.clear_resource_id_pool(
            pon_intf_id=0,
            resource_type=PONResourceManager.ALLOC_ID,
        )

        self.clear_resource_id_pool(
            pon_intf_id=0,
            resource_type=PONResourceManager.GEMPORT_ID,
        )

    def init_resource_id_pool(self, pon_intf_id, resource_type, start_idx,
                              end_idx):
        """
        Initialize Resource ID pool for a given Resource Type on a given PON Port

        :param pon_intf_id: OLT PON interface id
        :param resource_type: String to identify type of resource
        :param start_idx: start index for onu id pool
        :param end_idx: end index for onu id pool
        :return boolean: True if resource id pool initialized else false
        """
        status = False
        path = self._get_path(pon_intf_id, resource_type)
        if path is None:
            return status

        try:
            # In case of adapter reboot and reconciliation resource in kv store
            # checked for its presence if not kv store update happens
            resource = self._get_resource(path)

            if resource is not None:
                self._log.info("Resource-already-present-in-store", path=path)
                status = True
            else:
                resource = self._format_resource(pon_intf_id, start_idx,
                                                 end_idx)
                self._log.info("Resource-initialized", path=path)

                # Add resource as json in kv store.
                result = self._kv_store.update_to_kv_store(path, resource)
                if result is True:
                    status = True

        except Exception as e:
            self._log.exception("error-initializing-resource-pool", e=e)

        return status

    def get_resource_id(self, pon_intf_id, resource_type, num_of_id=1):
        """
        Create alloc/gemport/onu id for given OLT PON interface.

        :param pon_intf_id: OLT PON interface id
        :param resource_type: String to identify type of resource
        :param num_of_id: required number of ids
        :return list/int/None: list, int or None if resource type is
                               alloc_id/gemport_id, onu_id or invalid type
                               respectively
        """
        result = None

        # TODO: ASFvOLT16 platform requires alloc and gemport ID to be unique
        # across OLT. To keep it simple, a single pool (POOL 0) is maintained
        # for both the resource types. This may need to change later.
        # Override the incoming pon_intf_id to PON0
        if resource_type == PONResourceManager.GEMPORT_ID or \
                resource_type == PONResourceManager.ALLOC_ID:
            pon_intf_id = 0

        path = self._get_path(pon_intf_id, resource_type)
        if path is None:
            return result

        try:
            resource = self._get_resource(path)
            if resource is not None and resource_type == \
                    PONResourceManager.ONU_ID:
                result = self._generate_next_id(resource)
            elif resource is not None and (
                    resource_type == PONResourceManager.GEMPORT_ID or
                    resource_type == PONResourceManager.ALLOC_ID):
                result = list()
                while num_of_id > 0:
                    result.append(self._generate_next_id(resource))
                    num_of_id -= 1
            else:
                raise Exception("get-resource-failed")

            self._log.debug("Get-" + resource_type + "-success", result=result,
                            path=path)
            # Update resource in kv store
            self._update_resource(path, resource)

        except Exception as e:
            self._log.exception("Get-" + resource_type + "-id-failed",
                                path=path, e=e)
        return result

    def free_resource_id(self, pon_intf_id, resource_type, release_content):
        """
        Release alloc/gemport/onu id for given OLT PON interface.

        :param pon_intf_id: OLT PON interface id
        :param resource_type: String to identify type of resource
        :param release_content: required number of ids
        :return boolean: True if all IDs in given release_content released
                         else False
        """
        status = False

        # TODO: ASFvOLT16 platform requires alloc and gemport ID to be unique
        # across OLT. To keep it simple, a single pool (POOL 0) is maintained
        # for both the resource types. This may need to change later.
        # Override the incoming pon_intf_id to PON0
        if resource_type == PONResourceManager.GEMPORT_ID or \
                resource_type == PONResourceManager.ALLOC_ID:
            pon_intf_id = 0

        path = self._get_path(pon_intf_id, resource_type)
        if path is None:
            return status

        try:
            resource = self._get_resource(path)
            if resource is not None and resource_type == \
                    PONResourceManager.ONU_ID:
                self._release_id(resource, release_content)
            elif resource is not None and (
                    resource_type == PONResourceManager.ALLOC_ID or
                    resource_type == PONResourceManager.GEMPORT_ID):
                for content in release_content:
                    self._release_id(resource, content)
            else:
                raise Exception("get-resource-failed")

            self._log.debug("Free-" + resource_type + "-success", path=path)

            # Update resource in kv store
            status = self._update_resource(path, resource)

        except Exception as e:
            self._log.exception("Free-" + resource_type + "-failed",
                                path=path, e=e)
        return status

    def clear_resource_id_pool(self, pon_intf_id, resource_type):
        """
        Clear Resource Pool for a given Resource Type on a given PON Port.

        :return boolean: True if removed else False
        """
        path = self._get_path(pon_intf_id, resource_type)
        if path is None:
            return False

        try:
            result = self._kv_store.remove_from_kv_store(path)
            if result is True:
                self._log.debug("Resource-pool-cleared",
                                device_id=self.device_id,
                                path=path)
                return True
        except Exception as e:
            self._log.exception("error-clearing-resource-pool", e=e)

        self._log.error("Clear-resource-pool-failed", device_id=self.device_id,
                        path=path)
        return False

    def init_resource_map(self, pon_intf_onu_id):
        """
        Initialize resource map

        :param pon_intf_onu_id: reference of PON interface id and onu id
        """
        # initialize pon_intf_onu_id tuple to alloc_ids map
        alloc_id_path = PONResourceManager.ALLOC_ID_RESOURCE_MAP_PATH.format(
            self.device_id, str(pon_intf_onu_id)
        )
        alloc_ids = list()
        self._kv_store.update_to_kv_store(
            alloc_id_path, json.dumps(alloc_ids)
        )

        # initialize pon_intf_onu_id tuple to gemport_ids map
        gemport_id_path = PONResourceManager.GEMPORT_ID_RESOURCE_MAP_PATH.format(
            self.device_id, str(pon_intf_onu_id)
        )
        gemport_ids = list()
        self._kv_store.update_to_kv_store(
            gemport_id_path, json.dumps(gemport_ids)
        )

    def remove_resource_map(self, pon_intf_onu_id):
        """
        Remove resource map

        :param pon_intf_onu_id: reference of PON interface id and onu id
        """
        # remove pon_intf_onu_id tuple to alloc_ids map
        alloc_id_path = PONResourceManager.ALLOC_ID_RESOURCE_MAP_PATH.format(
            self.device_id, str(pon_intf_onu_id)
        )
        self._kv_store.remove_from_kv_store(alloc_id_path)

        # remove pon_intf_onu_id tuple to gemport_ids map
        gemport_id_path = PONResourceManager.GEMPORT_ID_RESOURCE_MAP_PATH.format(
            self.device_id, str(pon_intf_onu_id)
        )
        self._kv_store.remove_from_kv_store(gemport_id_path)

    def get_current_alloc_ids_for_onu(self, pon_intf_onu_id):
        """
        Get currently configured alloc ids for given pon_intf_onu_id

        :param pon_intf_onu_id: reference of PON interface id and onu id
        """
        path = PONResourceManager.ALLOC_ID_RESOURCE_MAP_PATH.format(
            self.device_id,
            str(pon_intf_onu_id))
        value = self._kv_store.get_from_kv_store(path)
        if value is not None:
            alloc_id_list = json.loads(value)
            if len(alloc_id_list) > 0:
                return alloc_id_list

        return None

    def get_current_gemport_ids_for_onu(self, pon_intf_onu_id):
        """
        Get currently configured gemport ids for given pon_intf_onu_id

        :param pon_intf_onu_id: reference of PON interface id and onu id
        """

        path = PONResourceManager.GEMPORT_ID_RESOURCE_MAP_PATH.format(
            self.device_id,
            str(pon_intf_onu_id))
        value = self._kv_store.get_from_kv_store(path)
        if value is not None:
            gemport_id_list = json.loads(value)
            if len(gemport_id_list) > 0:
                return gemport_id_list

        return None

    def update_alloc_ids_for_onu(self, pon_intf_onu_id, alloc_ids):
        """
        Update currently configured alloc ids for given pon_intf_onu_id

        :param pon_intf_onu_id: reference of PON interface id and onu id
        """
        path = PONResourceManager.ALLOC_ID_RESOURCE_MAP_PATH.format(
            self.device_id, str(pon_intf_onu_id)
        )
        self._kv_store.update_to_kv_store(
            path, json.dumps(alloc_ids)
        )

    def update_gemport_ids_for_onu(self, pon_intf_onu_id, gemport_ids):
        """
        Update currently configured gemport ids for given pon_intf_onu_id

        :param pon_intf_onu_id: reference of PON interface id and onu id
        """
        path = PONResourceManager.GEMPORT_ID_RESOURCE_MAP_PATH.format(
            self.device_id, str(pon_intf_onu_id)
        )
        self._kv_store.update_to_kv_store(
            path, json.dumps(gemport_ids)
        )

    def _get_olt_vendor(self):
        """
        Get olt vendor variant

        :return: type of olt vendor
        """
        olt_vendor = None
        if self.extra_args and len(self.extra_args) > 0:
            parser = OltVendorArgumentParser(add_help=False)
            parser.add_argument('--olt_vendor', '-o', action='store',
                                choices=['default', 'asfvolt16', 'cigolt24'],
                                default='default')
            try:
                args = parser.parse_args(shlex.split(self.extra_args))
                self._log.debug('parsing-extra-arguments', args=args)
                olt_vendor = args.olt_vendor
            except ArgumentError as e:
                self._log.exception('invalid-arguments: {}', e=e)
            except Exception as e:
                self._log.exception('option-parsing-error: {}', e=e)

        return olt_vendor

    def _generate_next_id(self, resource):
        """
        Generate unique id having OFFSET as start index.

        :param resource: resource used to generate ID
        :return int: generated id
        """
        pos = resource[PONResourceManager.POOL].find('0b0')
        resource[PONResourceManager.POOL].set(1, pos)
        return pos[0] + resource[PONResourceManager.START_IDX]

    def _release_id(self, resource, unique_id):
        """
        Release unique id having OFFSET as start index.

        :param resource: resource used to release ID
        :param unique_id: id need to be released
        """
        pos = ((int(unique_id)) - resource[PONResourceManager.START_IDX])
        resource[PONResourceManager.POOL].set(0, pos)

    def _get_path(self, pon_intf_id, resource_type):
        """
        Get path for given resource type.

        :param pon_intf_id: OLT PON interface id
        :param resource_type: String to identify type of resource
        :return: path for given resource type
        """
        path = None
        if resource_type == PONResourceManager.ONU_ID:
            path = self._get_onu_id_resource_path(pon_intf_id)
        elif resource_type == PONResourceManager.ALLOC_ID:
            path = self._get_alloc_id_resource_path(pon_intf_id)
        elif resource_type == PONResourceManager.GEMPORT_ID:
            path = self._get_gemport_id_resource_path(pon_intf_id)
        else:
            self._log.error("invalid-resource-pool-identifier")
        return path

    def _get_alloc_id_resource_path(self, pon_intf_id):
        """
        Get alloc id resource path.

        :param pon_intf_id: OLT PON interface id
        :return: alloc id resource path
        """
        return PONResourceManager.ALLOC_ID_POOL_PATH.format(
            self.device_id, pon_intf_id)

    def _get_gemport_id_resource_path(self, pon_intf_id):
        """
        Get gemport id resource path.

        :param pon_intf_id: OLT PON interface id
        :return: gemport id resource path
        """
        return PONResourceManager.GEMPORT_ID_POOL_PATH.format(
            self.device_id, pon_intf_id)

    def _get_onu_id_resource_path(self, pon_intf_id):
        """
        Get onu id resource path.

        :param pon_intf_id: OLT PON interface id
        :return: onu id resource path
        """
        return PONResourceManager.ONU_ID_POOL_PATH.format(
            self.device_id, pon_intf_id)

    def _update_resource(self, path, resource):
        """
        Update resource in resource kv store.

        :param path: path to update resource
        :param resource: resource need to be updated
        :return boolean: True if resource updated in kv store else False
        """
        resource[PONResourceManager.POOL] = \
            resource[PONResourceManager.POOL].bin
        result = self._kv_store.update_to_kv_store(path, json.dumps(resource))
        if result is True:
            return True
        return False

    def _get_resource(self, path):
        """
        Get resource from kv store.

        :param path: path to get resource
        :return: resource if resource present in kv store else None
        """
        # get resource from kv store
        result = self._kv_store.get_from_kv_store(path)
        if result is None:
            return result
        self._log.info("dumping resource", result=result)
        resource = result

        if resource is not None:
            # decode resource fetched from backend store to dictionary
            resource = json.loads(resource)

            # resource pool in backend store stored as binary string whereas to
            # access the pool to generate/release IDs it need to be converted
            # as BitArray
            resource[PONResourceManager.POOL] = \
                BitArray('0b' + resource[PONResourceManager.POOL])

        return resource

    def _format_resource(self, pon_intf_id, start_idx, end_idx):
        """
        Format resource as json.

        :param pon_intf_id: OLT PON interface id
        :param start_idx: start index for id pool
        :param end_idx: end index for id pool
        :return dictionary: resource formatted as dictionary
        """
        # Format resource as json to be stored in backend store
        resource = dict()
        resource[PONResourceManager.PON_INTF_ID] = pon_intf_id
        resource[PONResourceManager.START_IDX] = start_idx
        resource[PONResourceManager.END_IDX] = end_idx

        # resource pool stored in backend store as binary string
        resource[PONResourceManager.POOL] = BitArray(end_idx).bin

        return json.dumps(resource)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import meta_pb2 as meta__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='events.proto',
  package='voltha',
  syntax='proto3',
  serialized_pb=_b('\n\x0c\x65vents.proto\x12\x06voltha\x1a\nmeta.proto\x1a\x1cgoogle/api/annotations.proto\"E\n\x0f\x43onfigEventType\"2\n\x0f\x43onfigEventType\x12\x07\n\x03\x61\x64\x64\x10\x00\x12\n\n\x06remove\x10\x01\x12\n\n\x06update\x10\x02\"`\n\x0b\x43onfigEvent\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.voltha.ConfigEventType.ConfigEventType\x12\x0c\n\x04hash\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"1\n\x0cKpiEventType\"!\n\x0cKpiEventType\x12\t\n\x05slice\x10\x00\x12\x06\n\x02ts\x10\x01\"\xd2\x01\n\x0eMetricMetaData\x12\r\n\x05title\x18\x01 \x01(\t\x12\n\n\x02ts\x18\x02 \x01(\x01\x12\x19\n\x11logical_device_id\x18\x03 \x01(\t\x12\x11\n\tserial_no\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x05 \x01(\t\x12\x34\n\x07\x63ontext\x18\x06 \x03(\x0b\x32#.voltha.MetricMetaData.ContextEntry\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x10MetricValuePairs\x12\x36\n\x07metrics\x18\x01 \x03(\x0b\x32%.voltha.MetricValuePairs.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xa6\x01\n\x11MetricInformation\x12(\n\x08metadata\x18\x01 \x01(\x0b\x32\x16.voltha.MetricMetaData\x12\x37\n\x07metrics\x18\x02 \x03(\x0b\x32&.voltha.MetricInformation.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xc4\x01\n\x08KpiEvent\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.voltha.KpiEventType.KpiEventType\x12\n\n\x02ts\x18\x02 \x01(\x02\x12\x30\n\x08prefixes\x18\x03 \x03(\x0b\x32\x1e.voltha.KpiEvent.PrefixesEntry\x1aI\n\rPrefixesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.voltha.MetricValuePairs:\x02\x38\x01\"w\n\tKpiEvent2\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.voltha.KpiEventType.KpiEventType\x12\n\n\x02ts\x18\x02 \x01(\x01\x12-\n\nslice_data\x18\x03 \x03(\x0b\x32\x19.voltha.MetricInformation\"\x80\x01\n\x0e\x41larmEventType\"n\n\x0e\x41larmEventType\x12\x11\n\rCOMMUNICATION\x10\x00\x12\x0f\n\x0b\x45NVIRONMENT\x10\x01\x12\r\n\tEQUIPMENT\x10\x02\x12\x0b\n\x07SERVICE\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0c\n\x08SECURITY\x10\x05\"W\n\x12\x41larmEventCategory\"A\n\x12\x41larmEventCategory\x12\x07\n\x03PON\x10\x00\x12\x07\n\x03OLT\x10\x01\x12\x07\n\x03ONT\x10\x02\x12\x07\n\x03ONU\x10\x03\x12\x07\n\x03NNI\x10\x04\"=\n\x0f\x41larmEventState\"*\n\x0f\x41larmEventState\x12\n\n\x06RAISED\x10\x00\x12\x0b\n\x07\x43LEARED\x10\x01\"n\n\x12\x41larmEventSeverity\"X\n\x12\x41larmEventSeverity\x12\x11\n\rINDETERMINATE\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\t\n\x05MINOR\x10\x02\x12\t\n\x05MAJOR\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\"\x83\x04\n\nAlarmEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32%.voltha.AlarmEventType.AlarmEventType\x12?\n\x08\x63\x61tegory\x18\x03 \x01(\x0e\x32-.voltha.AlarmEventCategory.AlarmEventCategory\x12\x36\n\x05state\x18\x04 \x01(\x0e\x32\'.voltha.AlarmEventState.AlarmEventState\x12?\n\x08severity\x18\x05 \x01(\x0e\x32-.voltha.AlarmEventSeverity.AlarmEventSeverity\x12\x11\n\traised_ts\x18\x06 \x01(\x02\x12\x13\n\x0breported_ts\x18\x07 \x01(\x02\x12\x12\n\nchanged_ts\x18\x08 \x01(\x02\x12\x13\n\x0bresource_id\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x30\n\x07\x63ontext\x18\x0b \x03(\x0b\x32\x1f.voltha.AlarmEvent.ContextEntry\x12\x19\n\x11logical_device_id\x18\x0c \x01(\t\x12\x17\n\x0f\x61larm_type_name\x18\r \x01(\t\x1a.\n\x0c\x43ontextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42-Z+github.com/opencord/voltha-go/protos/volthab\x06proto3')
  ,
  dependencies=[meta__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_CONFIGEVENTTYPE_CONFIGEVENTTYPE = _descriptor.EnumDescriptor(
  name='ConfigEventType',
  full_name='voltha.ConfigEventType.ConfigEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='add', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='remove', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='update', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=85,
  serialized_end=135,
)
_sym_db.RegisterEnumDescriptor(_CONFIGEVENTTYPE_CONFIGEVENTTYPE)

_KPIEVENTTYPE_KPIEVENTTYPE = _descriptor.EnumDescriptor(
  name='KpiEventType',
  full_name='voltha.KpiEventType.KpiEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='slice', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ts', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=251,
  serialized_end=284,
)
_sym_db.RegisterEnumDescriptor(_KPIEVENTTYPE_KPIEVENTTYPE)

_ALARMEVENTTYPE_ALARMEVENTTYPE = _descriptor.EnumDescriptor(
  name='AlarmEventType',
  full_name='voltha.AlarmEventType.AlarmEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMUNICATION', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENVIRONMENT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EQUIPMENT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVICE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECURITY', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1131,
  serialized_end=1241,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTTYPE_ALARMEVENTTYPE)

_ALARMEVENTCATEGORY_ALARMEVENTCATEGORY = _descriptor.EnumDescriptor(
  name='AlarmEventCategory',
  full_name='voltha.AlarmEventCategory.AlarmEventCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PON', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OLT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONU', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NNI', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1265,
  serialized_end=1330,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTCATEGORY_ALARMEVENTCATEGORY)

_ALARMEVENTSTATE_ALARMEVENTSTATE = _descriptor.EnumDescriptor(
  name='AlarmEventState',
  full_name='voltha.AlarmEventState.AlarmEventState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAISED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLEARED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1351,
  serialized_end=1393,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTSTATE_ALARMEVENTSTATE)

_ALARMEVENTSEVERITY_ALARMEVENTSEVERITY = _descriptor.EnumDescriptor(
  name='AlarmEventSeverity',
  full_name='voltha.AlarmEventSeverity.AlarmEventSeverity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INDETERMINATE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINOR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAJOR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1417,
  serialized_end=1505,
)
_sym_db.RegisterEnumDescriptor(_ALARMEVENTSEVERITY_ALARMEVENTSEVERITY)


_CONFIGEVENTTYPE = _descriptor.Descriptor(
  name='ConfigEventType',
  full_name='voltha.ConfigEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONFIGEVENTTYPE_CONFIGEVENTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=135,
)


_CONFIGEVENT = _descriptor.Descriptor(
  name='ConfigEvent',
  full_name='voltha.ConfigEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.ConfigEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hash', full_name='voltha.ConfigEvent.hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='voltha.ConfigEvent.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=233,
)


_KPIEVENTTYPE = _descriptor.Descriptor(
  name='KpiEventType',
  full_name='voltha.KpiEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KPIEVENTTYPE_KPIEVENTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=284,
)


_METRICMETADATA_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='voltha.MetricMetaData.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.MetricMetaData.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.MetricMetaData.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=497,
)

_METRICMETADATA = _descriptor.Descriptor(
  name='MetricMetaData',
  full_name='voltha.MetricMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='title', full_name='voltha.MetricMetaData.title', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ts', full_name='voltha.MetricMetaData.ts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logical_device_id', full_name='voltha.MetricMetaData.logical_device_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='serial_no', full_name='voltha.MetricMetaData.serial_no', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='voltha.MetricMetaData.device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='voltha.MetricMetaData.context', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_METRICMETADATA_CONTEXTENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=497,
)


_METRICVALUEPAIRS_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='voltha.MetricValuePairs.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.MetricValuePairs.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.MetricValuePairs.MetricsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=621,
)

_METRICVALUEPAIRS = _descriptor.Descriptor(
  name='MetricValuePairs',
  full_name='voltha.MetricValuePairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.MetricValuePairs.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_METRICVALUEPAIRS_METRICSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=621,
)


_METRICINFORMATION_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='voltha.MetricInformation.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.MetricInformation.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.MetricInformation.MetricsEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=621,
)

_METRICINFORMATION = _descriptor.Descriptor(
  name='MetricInformation',
  full_name='voltha.MetricInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='voltha.MetricInformation.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='voltha.MetricInformation.metrics', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_METRICINFORMATION_METRICSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=624,
  serialized_end=790,
)


_KPIEVENT_PREFIXESENTRY = _descriptor.Descriptor(
  name='PrefixesEntry',
  full_name='voltha.KpiEvent.PrefixesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.KpiEvent.PrefixesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.KpiEvent.PrefixesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=916,
  serialized_end=989,
)

_KPIEVENT = _descriptor.Descriptor(
  name='KpiEvent',
  full_name='voltha.KpiEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.KpiEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ts', full_name='voltha.KpiEvent.ts', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='prefixes', full_name='voltha.KpiEvent.prefixes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_KPIEVENT_PREFIXESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=793,
  serialized_end=989,
)


_KPIEVENT2 = _descriptor.Descriptor(
  name='KpiEvent2',
  full_name='voltha.KpiEvent2',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.KpiEvent2.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ts', full_name='voltha.KpiEvent2.ts', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slice_data', full_name='voltha.KpiEvent2.slice_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1110,
)


_ALARMEVENTTYPE = _descriptor.Descriptor(
  name='AlarmEventType',
  full_name='voltha.AlarmEventType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTTYPE_ALARMEVENTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1113,
  serialized_end=1241,
)


_ALARMEVENTCATEGORY = _descriptor.Descriptor(
  name='AlarmEventCategory',
  full_name='voltha.AlarmEventCategory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTCATEGORY_ALARMEVENTCATEGORY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1330,
)


_ALARMEVENTSTATE = _descriptor.Descriptor(
  name='AlarmEventState',
  full_name='voltha.AlarmEventState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTSTATE_ALARMEVENTSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1332,
  serialized_end=1393,
)


_ALARMEVENTSEVERITY = _descriptor.Descriptor(
  name='AlarmEventSeverity',
  full_name='voltha.AlarmEventSeverity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALARMEVENTSEVERITY_ALARMEVENTSEVERITY,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1505,
)


_ALARMEVENT_CONTEXTENTRY = _descriptor.Descriptor(
  name='ContextEntry',
  full_name='voltha.AlarmEvent.ContextEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.AlarmEvent.ContextEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.AlarmEvent.ContextEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=497,
)

_ALARMEVENT = _descriptor.Descriptor(
  name='AlarmEvent',
  full_name='voltha.AlarmEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.AlarmEvent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.AlarmEvent.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='category', full_name='voltha.AlarmEvent.category', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='voltha.AlarmEvent.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='severity', full_name='voltha.AlarmEvent.severity', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='raised_ts', full_name='voltha.AlarmEvent.raised_ts', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reported_ts', full_name='voltha.AlarmEvent.reported_ts', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='changed_ts', full_name='voltha.AlarmEvent.changed_ts', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='voltha.AlarmEvent.resource_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='voltha.AlarmEvent.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='context', full_name='voltha.AlarmEvent.context', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logical_device_id', full_name='voltha.AlarmEvent.logical_device_id', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='alarm_type_name', full_name='voltha.AlarmEvent.alarm_type_name', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ALARMEVENT_CONTEXTENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1508,
  serialized_end=2023,
)

_CONFIGEVENTTYPE_CONFIGEVENTTYPE.containing_type = _CONFIGEVENTTYPE
_CONFIGEVENT.fields_by_name['type'].enum_type = _CONFIGEVENTTYPE_CONFIGEVENTTYPE
_KPIEVENTTYPE_KPIEVENTTYPE.containing_type = _KPIEVENTTYPE
_METRICMETADATA_CONTEXTENTRY.containing_type = _METRICMETADATA
_METRICMETADATA.fields_by_name['context'].message_type = _METRICMETADATA_CONTEXTENTRY
_METRICVALUEPAIRS_METRICSENTRY.containing_type = _METRICVALUEPAIRS
_METRICVALUEPAIRS.fields_by_name['metrics'].message_type = _METRICVALUEPAIRS_METRICSENTRY
_METRICINFORMATION_METRICSENTRY.containing_type = _METRICINFORMATION
_METRICINFORMATION.fields_by_name['metadata'].message_type = _METRICMETADATA
_METRICINFORMATION.fields_by_name['metrics'].message_type = _METRICINFORMATION_METRICSENTRY
_KPIEVENT_PREFIXESENTRY.fields_by_name['value'].message_type = _METRICVALUEPAIRS
_KPIEVENT_PREFIXESENTRY.containing_type = _KPIEVENT
_KPIEVENT.fields_by_name['type'].enum_type = _KPIEVENTTYPE_KPIEVENTTYPE
_KPIEVENT.fields_by_name['prefixes'].message_type = _KPIEVENT_PREFIXESENTRY
_KPIEVENT2.fields_by_name['type'].enum_type = _KPIEVENTTYPE_KPIEVENTTYPE
_KPIEVENT2.fields_by_name['slice_data'].message_type = _METRICINFORMATION
_ALARMEVENTTYPE_ALARMEVENTTYPE.containing_type = _ALARMEVENTTYPE
_ALARMEVENTCATEGORY_ALARMEVENTCATEGORY.containing_type = _ALARMEVENTCATEGORY
_ALARMEVENTSTATE_ALARMEVENTSTATE.containing_type = _ALARMEVENTSTATE
_ALARMEVENTSEVERITY_ALARMEVENTSEVERITY.containing_type = _ALARMEVENTSEVERITY
_ALARMEVENT_CONTEXTENTRY.containing_type = _ALARMEVENT
_ALARMEVENT.fields_by_name['type'].enum_type = _ALARMEVENTTYPE_ALARMEVENTTYPE
_ALARMEVENT.fields_by_name['category'].enum_type = _ALARMEVENTCATEGORY_ALARMEVENTCATEGORY
_ALARMEVENT.fields_by_name['state'].enum_type = _ALARMEVENTSTATE_ALARMEVENTSTATE
_ALARMEVENT.fields_by_name['severity'].enum_type = _ALARMEVENTSEVERITY_ALARMEVENTSEVERITY
_ALARMEVENT.fields_by_name['context'].message_type = _ALARMEVENT_CONTEXTENTRY
DESCRIPTOR.message_types_by_name['ConfigEventType'] = _CONFIGEVENTTYPE
DESCRIPTOR.message_types_by_name['ConfigEvent'] = _CONFIGEVENT
DESCRIPTOR.message_types_by_name['KpiEventType'] = _KPIEVENTTYPE
DESCRIPTOR.message_types_by_name['MetricMetaData'] = _METRICMETADATA
DESCRIPTOR.message_types_by_name['MetricValuePairs'] = _METRICVALUEPAIRS
DESCRIPTOR.message_types_by_name['MetricInformation'] = _METRICINFORMATION
DESCRIPTOR.message_types_by_name['KpiEvent'] = _KPIEVENT
DESCRIPTOR.message_types_by_name['KpiEvent2'] = _KPIEVENT2
DESCRIPTOR.message_types_by_name['AlarmEventType'] = _ALARMEVENTTYPE
DESCRIPTOR.message_types_by_name['AlarmEventCategory'] = _ALARMEVENTCATEGORY
DESCRIPTOR.message_types_by_name['AlarmEventState'] = _ALARMEVENTSTATE
DESCRIPTOR.message_types_by_name['AlarmEventSeverity'] = _ALARMEVENTSEVERITY
DESCRIPTOR.message_types_by_name['AlarmEvent'] = _ALARMEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConfigEventType = _reflection.GeneratedProtocolMessageType('ConfigEventType', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGEVENTTYPE,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ConfigEventType)
  ))
_sym_db.RegisterMessage(ConfigEventType)

ConfigEvent = _reflection.GeneratedProtocolMessageType('ConfigEvent', (_message.Message,), dict(
  DESCRIPTOR = _CONFIGEVENT,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ConfigEvent)
  ))
_sym_db.RegisterMessage(ConfigEvent)

KpiEventType = _reflection.GeneratedProtocolMessageType('KpiEventType', (_message.Message,), dict(
  DESCRIPTOR = _KPIEVENTTYPE,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.KpiEventType)
  ))
_sym_db.RegisterMessage(KpiEventType)

MetricMetaData = _reflection.GeneratedProtocolMessageType('MetricMetaData', (_message.Message,), dict(

  ContextEntry = _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), dict(
    DESCRIPTOR = _METRICMETADATA_CONTEXTENTRY,
    __module__ = 'events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.MetricMetaData.ContextEntry)
    ))
  ,
  DESCRIPTOR = _METRICMETADATA,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.MetricMetaData)
  ))
_sym_db.RegisterMessage(MetricMetaData)
_sym_db.RegisterMessage(MetricMetaData.ContextEntry)

MetricValuePairs = _reflection.GeneratedProtocolMessageType('MetricValuePairs', (_message.Message,), dict(

  MetricsEntry = _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), dict(
    DESCRIPTOR = _METRICVALUEPAIRS_METRICSENTRY,
    __module__ = 'events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.MetricValuePairs.MetricsEntry)
    ))
  ,
  DESCRIPTOR = _METRICVALUEPAIRS,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.MetricValuePairs)
  ))
_sym_db.RegisterMessage(MetricValuePairs)
_sym_db.RegisterMessage(MetricValuePairs.MetricsEntry)

MetricInformation = _reflection.GeneratedProtocolMessageType('MetricInformation', (_message.Message,), dict(

  MetricsEntry = _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), dict(
    DESCRIPTOR = _METRICINFORMATION_METRICSENTRY,
    __module__ = 'events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.MetricInformation.MetricsEntry)
    ))
  ,
  DESCRIPTOR = _METRICINFORMATION,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.MetricInformation)
  ))
_sym_db.RegisterMessage(MetricInformation)
_sym_db.RegisterMessage(MetricInformation.MetricsEntry)

KpiEvent = _reflection.GeneratedProtocolMessageType('KpiEvent', (_message.Message,), dict(

  PrefixesEntry = _reflection.GeneratedProtocolMessageType('PrefixesEntry', (_message.Message,), dict(
    DESCRIPTOR = _KPIEVENT_PREFIXESENTRY,
    __module__ = 'events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.KpiEvent.PrefixesEntry)
    ))
  ,
  DESCRIPTOR = _KPIEVENT,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.KpiEvent)
  ))
_sym_db.RegisterMessage(KpiEvent)
_sym_db.RegisterMessage(KpiEvent.PrefixesEntry)

KpiEvent2 = _reflection.GeneratedProtocolMessageType('KpiEvent2', (_message.Message,), dict(
  DESCRIPTOR = _KPIEVENT2,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.KpiEvent2)
  ))
_sym_db.RegisterMessage(KpiEvent2)

AlarmEventType = _reflection.GeneratedProtocolMessageType('AlarmEventType', (_message.Message,), dict(
  DESCRIPTOR = _ALARMEVENTTYPE,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventType)
  ))
_sym_db.RegisterMessage(AlarmEventType)

AlarmEventCategory = _reflection.GeneratedProtocolMessageType('AlarmEventCategory', (_message.Message,), dict(
  DESCRIPTOR = _ALARMEVENTCATEGORY,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventCategory)
  ))
_sym_db.RegisterMessage(AlarmEventCategory)

AlarmEventState = _reflection.GeneratedProtocolMessageType('AlarmEventState', (_message.Message,), dict(
  DESCRIPTOR = _ALARMEVENTSTATE,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventState)
  ))
_sym_db.RegisterMessage(AlarmEventState)

AlarmEventSeverity = _reflection.GeneratedProtocolMessageType('AlarmEventSeverity', (_message.Message,), dict(
  DESCRIPTOR = _ALARMEVENTSEVERITY,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEventSeverity)
  ))
_sym_db.RegisterMessage(AlarmEventSeverity)

AlarmEvent = _reflection.GeneratedProtocolMessageType('AlarmEvent', (_message.Message,), dict(

  ContextEntry = _reflection.GeneratedProtocolMessageType('ContextEntry', (_message.Message,), dict(
    DESCRIPTOR = _ALARMEVENT_CONTEXTENTRY,
    __module__ = 'events_pb2'
    # @@protoc_insertion_point(class_scope:voltha.AlarmEvent.ContextEntry)
    ))
  ,
  DESCRIPTOR = _ALARMEVENT,
  __module__ = 'events_pb2'
  # @@protoc_insertion_point(class_scope:voltha.AlarmEvent)
  ))
_sym_db.RegisterMessage(AlarmEvent)
_sym_db.RegisterMessage(AlarmEvent.ContextEntry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z+github.com/opencord/voltha-go/protos/voltha'))
_METRICMETADATA_CONTEXTENTRY.has_options = True
_METRICMETADATA_CONTEXTENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_METRICVALUEPAIRS_METRICSENTRY.has_options = True
_METRICVALUEPAIRS_METRICSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_METRICINFORMATION_METRICSENTRY.has_options = True
_METRICINFORMATION_METRICSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_KPIEVENT_PREFIXESENTRY.has_options = True
_KPIEVENT_PREFIXESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_ALARMEVENT_CONTEXTENTRY.has_options = True
_ALARMEVENT_CONTEXTENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inter_container.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
import openflow_13_pb2 as openflow__13__pb2
try:
  yang__options__pb2 = openflow__13__pb2.yang__options__pb2
except AttributeError:
  yang__options__pb2 = openflow__13__pb2.yang_options_pb2
import logical_device_pb2 as logical__device__pb2

from logical_device_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='inter_container.proto',
  package='voltha',
  syntax='proto3',
  serialized_pb=_b('\n\x15inter_container.proto\x12\x06voltha\x1a\x19google/protobuf/any.proto\x1a\x11openflow_13.proto\x1a\x14logical_device.proto\"\x16\n\x07StrType\x12\x0b\n\x03val\x18\x01 \x01(\t\"\x16\n\x07IntType\x12\x0b\n\x03val\x18\x01 \x01(\x03\"\x17\n\x08\x42oolType\x12\x0b\n\x03val\x18\x01 \x01(\x08\"\x19\n\x06Packet\x12\x0f\n\x07payload\x18\x01 \x01(\x0c\"E\n\tErrorCode\"8\n\x05\x63odes\x12\x17\n\x13UNSUPPORTED_REQUEST\x10\x00\x12\x16\n\x12INVALID_PARAMETERS\x10\x01\"8\n\x05\x45rror\x12\x1f\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x11.voltha.ErrorCode\x12\x0e\n\x06reason\x18\x02 \x01(\t\"p\n\x06Header\x12\n\n\x02id\x18\x01 \x01(\t\x12!\n\x04type\x18\x02 \x01(\x0e\x32\x13.voltha.MessageType\x12\x12\n\nfrom_topic\x18\x03 \x01(\t\x12\x10\n\x08to_topic\x18\x04 \x01(\t\x12\x11\n\ttimestamp\x18\x05 \x01(\x03\"<\n\x08\x41rgument\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"[\n\x15InterContainerMessage\x12\x1e\n\x06header\x18\x01 \x01(\x0b\x32\x0e.voltha.Header\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"{\n\x19InterContainerRequestBody\x12\x0b\n\x03rpc\x18\x02 \x01(\t\x12\x1e\n\x04\x61rgs\x18\x03 \x03(\x0b\x32\x10.voltha.Argument\x12\x19\n\x11response_required\x18\x04 \x01(\x08\x12\x16\n\x0ereply_to_topic\x18\x05 \x01(\t\"S\n\x1aInterContainerResponseBody\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12$\n\x06result\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"r\n\x10SwitchCapability\x12#\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x02 \x01(\x0b\x32 .openflow_13.ofp_switch_features\"3\n\x0ePortCapability\x12!\n\x04port\x18\x01 \x01(\x0b\x32\x13.voltha.LogicalPort\"Y\n\x10\x44\x65viceDiscovered\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t\x12\x11\n\tpublisher\x18\x04 \x01(\t\"\x97\x01\n\x17InterAdapterMessageType\"|\n\x05Types\x12\x10\n\x0c\x46LOW_REQUEST\x10\x00\x12\x11\n\rFLOW_RESPONSE\x10\x01\x12\x10\n\x0cOMCI_REQUEST\x10\x02\x12\x11\n\rOMCI_RESPONSE\x10\x03\x12\x13\n\x0fMETRICS_REQUEST\x10\x04\x12\x14\n\x10METRICS_RESPONSE\x10\x05\"\xbd\x01\n\x12InterAdapterHeader\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32%.voltha.InterAdapterMessageType.Types\x12\x12\n\nfrom_topic\x18\x03 \x01(\t\x12\x10\n\x08to_topic\x18\x04 \x01(\t\x12\x14\n\x0cto_device_id\x18\x05 \x01(\t\x12\x17\n\x0fproxy_device_id\x18\x06 \x01(\t\x12\x11\n\ttimestamp\x18\x07 \x01(\x03\"N\n\x18InterAdapterResponseBody\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"e\n\x13InterAdapterMessage\x12*\n\x06header\x18\x01 \x01(\x0b\x32\x1a.voltha.InterAdapterHeader\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any*?\n\x0bMessageType\x12\x0b\n\x07REQUEST\x10\x00\x12\x0c\n\x08RESPONSE\x10\x01\x12\x15\n\x11\x44\x45VICE_DISCOVERED\x10\x02\x42\x36Z4github.com/opencord/voltha-go/protos/inter_containerP\x02\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,openflow__13__pb2.DESCRIPTOR,logical__device__pb2.DESCRIPTOR,],
  public_dependencies=[logical__device__pb2.DESCRIPTOR,])

_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='voltha.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESPONSE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_DISCOVERED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1598,
  serialized_end=1661,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
REQUEST = 0
RESPONSE = 1
DEVICE_DISCOVERED = 2


_ERRORCODE_CODES = _descriptor.EnumDescriptor(
  name='codes',
  full_name='voltha.ErrorCode.codes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED_REQUEST', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PARAMETERS', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=214,
  serialized_end=270,
)
_sym_db.RegisterEnumDescriptor(_ERRORCODE_CODES)

_INTERADAPTERMESSAGETYPE_TYPES = _descriptor.EnumDescriptor(
  name='Types',
  full_name='voltha.InterAdapterMessageType.Types',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLOW_REQUEST', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOW_RESPONSE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OMCI_REQUEST', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OMCI_RESPONSE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METRICS_REQUEST', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='METRICS_RESPONSE', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1097,
  serialized_end=1221,
)
_sym_db.RegisterEnumDescriptor(_INTERADAPTERMESSAGETYPE_TYPES)


_STRTYPE = _descriptor.Descriptor(
  name='StrType',
  full_name='voltha.StrType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='voltha.StrType.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=123,
)


_INTTYPE = _descriptor.Descriptor(
  name='IntType',
  full_name='voltha.IntType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='voltha.IntType.val', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=147,
)


_BOOLTYPE = _descriptor.Descriptor(
  name='BoolType',
  full_name='voltha.BoolType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='voltha.BoolType.val', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=172,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='voltha.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='voltha.Packet.payload', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=174,
  serialized_end=199,
)


_ERRORCODE = _descriptor.Descriptor(
  name='ErrorCode',
  full_name='voltha.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ERRORCODE_CODES,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=270,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='voltha.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='voltha.Error.code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reason', full_name='voltha.Error.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=328,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='voltha.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.Header.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.Header.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_topic', full_name='voltha.Header.from_topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_topic', full_name='voltha.Header.to_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='voltha.Header.timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=442,
)


_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='voltha.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voltha.Argument.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='voltha.Argument.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=504,
)


_INTERCONTAINERMESSAGE = _descriptor.Descriptor(
  name='InterContainerMessage',
  full_name='voltha.InterContainerMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='voltha.InterContainerMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='voltha.InterContainerMessage.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=506,
  serialized_end=597,
)


_INTERCONTAINERREQUESTBODY = _descriptor.Descriptor(
  name='InterContainerRequestBody',
  full_name='voltha.InterContainerRequestBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rpc', full_name='voltha.InterContainerRequestBody.rpc', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='args', full_name='voltha.InterContainerRequestBody.args', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='response_required', full_name='voltha.InterContainerRequestBody.response_required', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reply_to_topic', full_name='voltha.InterContainerRequestBody.reply_to_topic', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=722,
)


_INTERCONTAINERRESPONSEBODY = _descriptor.Descriptor(
  name='InterContainerResponseBody',
  full_name='voltha.InterContainerResponseBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='voltha.InterContainerResponseBody.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='voltha.InterContainerResponseBody.result', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=807,
)


_SWITCHCAPABILITY = _descriptor.Descriptor(
  name='SwitchCapability',
  full_name='voltha.SwitchCapability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='voltha.SwitchCapability.desc', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='switch_features', full_name='voltha.SwitchCapability.switch_features', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=923,
)


_PORTCAPABILITY = _descriptor.Descriptor(
  name='PortCapability',
  full_name='voltha.PortCapability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='voltha.PortCapability.port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=976,
)


_DEVICEDISCOVERED = _descriptor.Descriptor(
  name='DeviceDiscovered',
  full_name='voltha.DeviceDiscovered',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.DeviceDiscovered.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_id', full_name='voltha.DeviceDiscovered.parent_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='voltha.DeviceDiscovered.device_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='publisher', full_name='voltha.DeviceDiscovered.publisher', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=978,
  serialized_end=1067,
)


_INTERADAPTERMESSAGETYPE = _descriptor.Descriptor(
  name='InterAdapterMessageType',
  full_name='voltha.InterAdapterMessageType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERADAPTERMESSAGETYPE_TYPES,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1070,
  serialized_end=1221,
)


_INTERADAPTERHEADER = _descriptor.Descriptor(
  name='InterAdapterHeader',
  full_name='voltha.InterAdapterHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='voltha.InterAdapterHeader.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='voltha.InterAdapterHeader.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='from_topic', full_name='voltha.InterAdapterHeader.from_topic', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_topic', full_name='voltha.InterAdapterHeader.to_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to_device_id', full_name='voltha.InterAdapterHeader.to_device_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='proxy_device_id', full_name='voltha.InterAdapterHeader.proxy_device_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='voltha.InterAdapterHeader.timestamp', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1224,
  serialized_end=1413,
)


_INTERADAPTERRESPONSEBODY = _descriptor.Descriptor(
  name='InterAdapterResponseBody',
  full_name='voltha.InterAdapterResponseBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='voltha.InterAdapterResponseBody.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='voltha.InterAdapterResponseBody.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1415,
  serialized_end=1493,
)


_INTERADAPTERMESSAGE = _descriptor.Descriptor(
  name='InterAdapterMessage',
  full_name='voltha.InterAdapterMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='voltha.InterAdapterMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='voltha.InterAdapterMessage.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1495,
  serialized_end=1596,
)

_ERRORCODE_CODES.containing_type = _ERRORCODE
_ERROR.fields_by_name['code'].message_type = _ERRORCODE
_HEADER.fields_by_name['type'].enum_type = _MESSAGETYPE
_ARGUMENT.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INTERCONTAINERMESSAGE.fields_by_name['header'].message_type = _HEADER
_INTERCONTAINERMESSAGE.fields_by_name['body'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INTERCONTAINERREQUESTBODY.fields_by_name['args'].message_type = _ARGUMENT
_INTERCONTAINERRESPONSEBODY.fields_by_name['result'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SWITCHCAPABILITY.fields_by_name['desc'].message_type = openflow__13__pb2._OFP_DESC
_SWITCHCAPABILITY.fields_by_name['switch_features'].message_type = openflow__13__pb2._OFP_SWITCH_FEATURES
_PORTCAPABILITY.fields_by_name['port'].message_type = logical__device__pb2._LOGICALPORT
_INTERADAPTERMESSAGETYPE_TYPES.containing_type = _INTERADAPTERMESSAGETYPE
_INTERADAPTERHEADER.fields_by_name['type'].enum_type = _INTERADAPTERMESSAGETYPE_TYPES
_INTERADAPTERRESPONSEBODY.fields_by_name['body'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INTERADAPTERMESSAGE.fields_by_name['header'].message_type = _INTERADAPTERHEADER
_INTERADAPTERMESSAGE.fields_by_name['body'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['StrType'] = _STRTYPE
DESCRIPTOR.message_types_by_name['IntType'] = _INTTYPE
DESCRIPTOR.message_types_by_name['BoolType'] = _BOOLTYPE
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
DESCRIPTOR.message_types_by_name['ErrorCode'] = _ERRORCODE
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Argument'] = _ARGUMENT
DESCRIPTOR.message_types_by_name['InterContainerMessage'] = _INTERCONTAINERMESSAGE
DESCRIPTOR.message_types_by_name['InterContainerRequestBody'] = _INTERCONTAINERREQUESTBODY
DESCRIPTOR.message_types_by_name['InterContainerResponseBody'] = _INTERCONTAINERRESPONSEBODY
DESCRIPTOR.message_types_by_name['SwitchCapability'] = _SWITCHCAPABILITY
DESCRIPTOR.message_types_by_name['PortCapability'] = _PORTCAPABILITY
DESCRIPTOR.message_types_by_name['DeviceDiscovered'] = _DEVICEDISCOVERED
DESCRIPTOR.message_types_by_name['InterAdapterMessageType'] = _INTERADAPTERMESSAGETYPE
DESCRIPTOR.message_types_by_name['InterAdapterHeader'] = _INTERADAPTERHEADER
DESCRIPTOR.message_types_by_name['InterAdapterResponseBody'] = _INTERADAPTERRESPONSEBODY
DESCRIPTOR.message_types_by_name['InterAdapterMessage'] = _INTERADAPTERMESSAGE
DESCRIPTOR.enum_types_by_name['MessageType'] = _MESSAGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StrType = _reflection.GeneratedProtocolMessageType('StrType', (_message.Message,), dict(
  DESCRIPTOR = _STRTYPE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.StrType)
  ))
_sym_db.RegisterMessage(StrType)

IntType = _reflection.GeneratedProtocolMessageType('IntType', (_message.Message,), dict(
  DESCRIPTOR = _INTTYPE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.IntType)
  ))
_sym_db.RegisterMessage(IntType)

BoolType = _reflection.GeneratedProtocolMessageType('BoolType', (_message.Message,), dict(
  DESCRIPTOR = _BOOLTYPE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.BoolType)
  ))
_sym_db.RegisterMessage(BoolType)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), dict(
  DESCRIPTOR = _PACKET,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Packet)
  ))
_sym_db.RegisterMessage(Packet)

ErrorCode = _reflection.GeneratedProtocolMessageType('ErrorCode', (_message.Message,), dict(
  DESCRIPTOR = _ERRORCODE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.ErrorCode)
  ))
_sym_db.RegisterMessage(ErrorCode)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Error)
  ))
_sym_db.RegisterMessage(Error)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
  DESCRIPTOR = _HEADER,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Header)
  ))
_sym_db.RegisterMessage(Header)

Argument = _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), dict(
  DESCRIPTOR = _ARGUMENT,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.Argument)
  ))
_sym_db.RegisterMessage(Argument)

InterContainerMessage = _reflection.GeneratedProtocolMessageType('InterContainerMessage', (_message.Message,), dict(
  DESCRIPTOR = _INTERCONTAINERMESSAGE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterContainerMessage)
  ))
_sym_db.RegisterMessage(InterContainerMessage)

InterContainerRequestBody = _reflection.GeneratedProtocolMessageType('InterContainerRequestBody', (_message.Message,), dict(
  DESCRIPTOR = _INTERCONTAINERREQUESTBODY,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterContainerRequestBody)
  ))
_sym_db.RegisterMessage(InterContainerRequestBody)

InterContainerResponseBody = _reflection.GeneratedProtocolMessageType('InterContainerResponseBody', (_message.Message,), dict(
  DESCRIPTOR = _INTERCONTAINERRESPONSEBODY,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterContainerResponseBody)
  ))
_sym_db.RegisterMessage(InterContainerResponseBody)

SwitchCapability = _reflection.GeneratedProtocolMessageType('SwitchCapability', (_message.Message,), dict(
  DESCRIPTOR = _SWITCHCAPABILITY,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.SwitchCapability)
  ))
_sym_db.RegisterMessage(SwitchCapability)

PortCapability = _reflection.GeneratedProtocolMessageType('PortCapability', (_message.Message,), dict(
  DESCRIPTOR = _PORTCAPABILITY,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.PortCapability)
  ))
_sym_db.RegisterMessage(PortCapability)

DeviceDiscovered = _reflection.GeneratedProtocolMessageType('DeviceDiscovered', (_message.Message,), dict(
  DESCRIPTOR = _DEVICEDISCOVERED,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.DeviceDiscovered)
  ))
_sym_db.RegisterMessage(DeviceDiscovered)

InterAdapterMessageType = _reflection.GeneratedProtocolMessageType('InterAdapterMessageType', (_message.Message,), dict(
  DESCRIPTOR = _INTERADAPTERMESSAGETYPE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterMessageType)
  ))
_sym_db.RegisterMessage(InterAdapterMessageType)

InterAdapterHeader = _reflection.GeneratedProtocolMessageType('InterAdapterHeader', (_message.Message,), dict(
  DESCRIPTOR = _INTERADAPTERHEADER,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterHeader)
  ))
_sym_db.RegisterMessage(InterAdapterHeader)

InterAdapterResponseBody = _reflection.GeneratedProtocolMessageType('InterAdapterResponseBody', (_message.Message,), dict(
  DESCRIPTOR = _INTERADAPTERRESPONSEBODY,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterResponseBody)
  ))
_sym_db.RegisterMessage(InterAdapterResponseBody)

InterAdapterMessage = _reflection.GeneratedProtocolMessageType('InterAdapterMessage', (_message.Message,), dict(
  DESCRIPTOR = _INTERADAPTERMESSAGE,
  __module__ = 'inter_container_pb2'
  # @@protoc_insertion_point(class_scope:voltha.InterAdapterMessage)
  ))
_sym_db.RegisterMessage(InterAdapterMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z4github.com/opencord/voltha-go/protos/inter_container'))
# @@protoc_insertion_point(module_scope)
